package cn.iocoder.yudao.module.inspection.service;

import com.baomidou.mybatisplus.extension.service.IService;
import cn.iocoder.yudao.module.inspection.entity.InspectionNewsComment;

import java.util.List;

/**
 * 【请填写功能名称】Service接口
 *
 * @author ruoyi
 * @date 2023-08-07
 */
public interface IInspectionNewsCommentService extends IService<InspectionNewsComment>
{
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public InspectionNewsComment selectInspectionNewsCommentById(Long id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param inspectionNewsComment 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<InspectionNewsComment> selectInspectionNewsCommentList(InspectionNewsComment inspectionNewsComment);

    /**
     * 新增【请填写功能名称】
     *
     * @param inspectionNewsComment 【请填写功能名称】
     * @return 结果
     */
    public int insertInspectionNewsComment(InspectionNewsComment inspectionNewsComment);

    /**
     * 修改【请填写功能名称】
     *
     * @param inspectionNewsComment 【请填写功能名称】
     * @return 结果
     */
    public int updateInspectionNewsComment(InspectionNewsComment inspectionNewsComment);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteInspectionNewsCommentByIds(Long[] ids);

    /**
     * 删除【请填写功能名称】信息
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteInspectionNewsCommentById(Long id);
}
